/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.cache;

import android.content.Context;
import android.content.SharedPreferences;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.media.R;

/**
 * Sort preferences
 */
public class SortPreference {
    public static final String SORT_PREFS_NAME = "sort_preference";
    public static final String SORT_SELECTION = "sort_selection";

    public static void setSortPreference(Context context, String sortPreference) {
        SharedPreferences prefs = context.getSharedPreferences(SORT_PREFS_NAME, 0);
        SharedPreferences.Editor edit = prefs.edit();
        edit.putString(SORT_SELECTION, sortPreference);
        edit.commit();
    }

    public static String getSortPreference(Context context) {
        SharedPreferences prefs = context.getSharedPreferences(SORT_PREFS_NAME, 0);
        return prefs.getString(SORT_SELECTION, "");
    }

    public static String getSortColumn(Context context, String nameColumn) {
        if(getSortPreference(context).equals(context.getString(R.string.sort_name))) {
            return nameColumn;
        } else {
            // default it to date even if sort pref isn't stored.
            return CloudAPI.Search.CREATED_DATE + " DESC";
        }
    }

    public static SortType getSortType(Context context) {
        if(getSortPreference(context).equals(context.getString(R.string.sort_name))) {
            return SortType.NAME.setOrder(SortType.SortOrder.ASC);
        } else {
            // default it to date even if sort pref isn't stored.
            return SortType.VERSION_CREATED.setOrder(SortType.SortOrder.DESC);
        }
    }

    public static String getPlaylistSortColumn(Context context, String nameColumn) {
        if(getSortPreference(context).equals(context.getString(R.string.sort_name))) {
            return nameColumn;
        } else {
            // default it to date even if sort pref isn't stored.
            return CloudAPI.Search.CREATED_DATE + " DESC";
        }
    }
}
