/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.dialog;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.Spinner;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.PlaylistType;
import com.thingspace.cloud.sdk.list.item.Playlist;
import com.thingspace.media.R;
import com.thingspace.media.activities.PlaylistItemsActivity;
import com.thingspace.media.activities.SearchResultActivity;
import com.thingspace.media.fragments.BaseFragment;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.playlist.CreatePlaylistTask;
import com.thingspace.media.tasks.HubbleMediaTask;
import com.thingspace.media.tasks.playlist.UpdatePlaylistTask;

/**
 * This class calls:
 * 1) CreatePlaylistTask which makes a cloud SDK API call to create a playlist under user's cloud storage account.
 * 2) UpdatePlaylistTask which makes a Cloud SDK API call to Update the name of the existing playlist.
 */
public class CreatePlaylistDialog extends DialogFragment implements ThingspaceResponseListener {

    public static final String EXTRA_PLAYLIST_TYPE = "extra_playlist_type";
    public static final String EXTRA_PLAYLIST_ACTION = "extra_playlist_action";
    public static final String EXTRA_PLAYLIST_UID = "extra_playlist_uid";
    public static final String EXTRA_PLAYLIST_NAME = "extra_playlist_name";
    public static final String EXTRA_PLAYLIST_SELECTED_TYPE = "extra_playlist_selected_type";
    public static final String ACTION_PLAYLIST_CREATE = "create";
    public static final String ACTION_PLAYLIST_UDPATE = "update";
    public static final String ACTION_PLAYLIST_UDPATE_DEFINITION = "update_definition";

    public static final int TYPE_IMAGE_VIDEO = 1;
    public static final int TYPE_MUSIC = 2;
    private static CloudAPI cloudAPI;

    private EditText playlistName;
    private int requestType, contentType;
    private String action, uid, name, selectedType;

    public static void setCloudAPI(CloudAPI aCloudAPI) {
        cloudAPI = aCloudAPI;
    }

    public Dialog onCreateDialog(Bundle savedInstanceState) {

        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());
        LayoutInflater inflater = getActivity().getLayoutInflater();

        View dialogView = inflater.inflate(R.layout.dialog_create_playlist, null);
        builder.setView(dialogView);

        requestType = getArguments().getInt(EXTRA_PLAYLIST_TYPE, 1);
        action = getArguments().getString(EXTRA_PLAYLIST_ACTION);
        uid = getArguments().getString(EXTRA_PLAYLIST_UID);
        name = getArguments().getString(EXTRA_PLAYLIST_NAME);
        selectedType = getArguments().getString(EXTRA_PLAYLIST_SELECTED_TYPE);

        playlistName = (EditText) dialogView.findViewById(R.id.new_playlist_name);
        if (action.equalsIgnoreCase(ACTION_PLAYLIST_CREATE)) {
            playlistName.setHint(requestType == 1 ? R.string.album_name : R.string.playlist_name);
        } else {
            playlistName.setText(name);
        }

        int typeArray = requestType == 1 ? R.array.playlist_types_image_video : R.array.playlist_types_music;
        final Spinner spinner = (Spinner) dialogView.findViewById(R.id.spinnerPlaylistTypes);
        final ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(getActivity(), typeArray, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinner.setAdapter(adapter);
        spinner.setVisibility(View.VISIBLE);

        if (action.equalsIgnoreCase(ACTION_PLAYLIST_UDPATE_DEFINITION) || action.equalsIgnoreCase(ACTION_PLAYLIST_UDPATE)) {
            spinner.setSelection(getSelectedTypePosition(selectedType, typeArray));
        }

        if (action.equalsIgnoreCase(ACTION_PLAYLIST_UDPATE)) {
            spinner.setVisibility(View.GONE);
            dialogView.findViewById(R.id.playlistTypesText).setVisibility(View.GONE);
        }

        builder.setPositiveButton(ACTION_PLAYLIST_CREATE.equalsIgnoreCase(action) ? R.string.create : R.string.update,
                new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        String selectedType = spinner.getSelectedItem().toString();
                        PlaylistType playlistType = PlaylistType.IMAGE;
                        contentType = PlaylistItemsActivity.CONTENT_TYPE_IMAGE;
                        if (PlaylistType.VIDEO.toString().equalsIgnoreCase(selectedType)) {
                            playlistType = PlaylistType.VIDEO;
                            contentType = PlaylistItemsActivity.CONTENT_TYPE_VIDEO;
                        } else if (PlaylistType.IMAGE_VIDEO.toString().equalsIgnoreCase(selectedType)) {
                            playlistType = PlaylistType.IMAGE_VIDEO;
                            contentType = PlaylistItemsActivity.CONTENT_TYPE_IMAGE_VIDEO;
                        } else if (PlaylistType.MUSIC.toString().equalsIgnoreCase(selectedType)) {
                            playlistType = PlaylistType.MUSIC;
                            contentType = PlaylistItemsActivity.CONTENT_TYPE_MUSIC;
                        }

                        if (ACTION_PLAYLIST_CREATE.equalsIgnoreCase(action)) {
                            /**
                             * CreatePlaylistTask makes a cloud SDK API call to create a playlist under user's cloud storage account.
                             */
                            CreatePlaylistTask createPlaylistTask = new CreatePlaylistTask(getActivity(), CreatePlaylistDialog.this, cloudAPI, playlistName.getText().toString(), null, playlistType);
                            createPlaylistTask.execute();
                        } else if (ACTION_PLAYLIST_UDPATE.equalsIgnoreCase(action)) {
                            /**
                             * UpdatePlaylistTask makes a Cloud SDK API call to Update the name of the existing playlist.
                             */
                            UpdatePlaylistTask updatePlaylistTask = new UpdatePlaylistTask(getActivity(), CreatePlaylistDialog.this, cloudAPI, uid, playlistName.getText().toString());
                            updatePlaylistTask.execute();
                        } else if (ACTION_PLAYLIST_UDPATE_DEFINITION.equalsIgnoreCase(action)) {
                            String query = null;
                            String title = null;
                            switch (contentType) {
                                case PlaylistItemsActivity.CONTENT_TYPE_MUSIC:
                                    query = CloudAPI.Search.MIME_TYPE + " LIKE '%audio%'";
                                    title = "Music";
                                    break;
                                case PlaylistItemsActivity.CONTENT_TYPE_IMAGE:
                                    query = CloudAPI.Search.MIME_TYPE + " LIKE '%image%'";
                                    title = "Photos";
                                    break;
                                case PlaylistItemsActivity.CONTENT_TYPE_VIDEO:
                                    query = CloudAPI.Search.MIME_TYPE + " LIKE '%video%'";
                                    title = "Videos";
                                    break;
                                case PlaylistItemsActivity.CONTENT_TYPE_IMAGE_VIDEO:
                                    query = CloudAPI.Search.MIME_TYPE + " LIKE '%image%' OR " + CloudAPI.Search.MIME_TYPE + " LIKE '%video%'";
                                    title = "Photos/Videos";

                            }
                            Intent intent = new Intent(getActivity(), SearchResultActivity.class);
                            intent.putExtra(SearchResultActivity.EXTRA_QUERY, query);
                            intent.putExtra(SearchResultActivity.EXTRA_VIEW_MODE, SearchResultActivity.VIEW_MODE_SELECTION);
                            intent.putExtra(SearchResultActivity.EXTRA_TITLE, title);
                            intent.putExtra(SearchResultActivity.EXTRA_NAME, playlistName.getText().toString());
                            intent.putExtra(SearchResultActivity.EXTRA_UID, uid);
                            intent.putExtra(SearchResultActivity.EXTRA_PLAYLIST_TYPE, contentType);
                            startActivityForResult(intent, HubbleMediaTask.TASK_UPDATE_PLAYLIST_DEFINITION);
                        }
                    }
                });

        builder.setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int id) {
                CreatePlaylistDialog.this.getDialog().cancel();
            }
        });

        AlertDialog dialog = builder.create();
        dialog.setTitle(ACTION_PLAYLIST_CREATE.equalsIgnoreCase(action) ? (requestType == 1 ? R.string.create_album : R.string.create_playlist) :
                (requestType == 1 ? R.string.update_album : R.string.update_playlist));
        dialog.show();
        return dialog;
    }

    private int getSelectedTypePosition(String type, int typeArray) {
        String[] typeArrayList = getResources().getStringArray(typeArray);
        if (typeArrayList[0].equalsIgnoreCase(type)) {
            return 0;
        } else if (typeArrayList.length > 1 && typeArrayList[1].equalsIgnoreCase(type)) {
            return 1;
        } else if (typeArrayList.length > 2 && typeArrayList[2].equalsIgnoreCase(type)) {
            return 2;
        }
        return 0;
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_CREATE_PLAYLIST || taskCode == HubbleMediaTask.TASK_UPDATE_PLAYLIST
                || taskCode == HubbleMediaTask.TASK_UPDATE_PLAYLIST_DEFINITION) {
            if (response instanceof Playlist) {
                Playlist playlist = (Playlist) response;
                Log.d("Playlist Created", "name: " + playlist.getName());
                Log.d("Playlist Created", "uid: " + playlist.getUid());
                Log.d("Playlist Created", "type: " + playlist.getType());
                Log.d("Playlist Created", "Creation Date: " + playlist.getCreationDate());

                if (getTargetFragment() instanceof BaseFragment) {
                    ((BaseFragment) getTargetFragment()).executeQuery();
                }
            }
        }
    }
}
