/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.fragments;

import android.util.Log;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.media.cache.SortPreference;
import com.thingspace.media.tasks.GetDocumentsTask;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * DocumentsGridFragment is called when "Documents" Tab is selected in Photos/Videos which displays all the Documents stored in the cloud.
 * This Fragment calls GetDocumentsTask which in turn makes a Cloud SDK API call to retrieve all the documents stored in user's cloud storage account.
 */
public class DocumentsGridFragment extends BaseFragment {

    public void executeQuery() {
        /**
         * GetDocumentsTask makes a Cloud SDK API call to retrieve all the documents stored in user's cloud storage account.
         */
        GetDocumentsTask task = new GetDocumentsTask(getActivity(), this, cloudAPI, SortPreference.getSortType(getActivity()));
        task.execute();
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_GET_DOCUMENTS) {
            if (response instanceof ItemList) {
                itemList = (ItemList) response;
                recyclerView.setAdapter(getRecyclerViewAdapter(itemList));
                for (int i = 0; i < itemList.getCount(); i++) {
                    File file = (File) itemList.getItem(i);
                    Log.e("----------->", "Name: " + file.getName() + " - Mime: " + file.getMimeType());
                }
            }
        }
    }
}
