/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.fragments;

import android.content.Intent;
import android.support.v7.widget.RecyclerView;
import android.view.View;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Artist;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.media.R;
import com.thingspace.media.activities.ArtistGenreFilesActivity;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewListAdapter;
import com.thingspace.media.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.media.tasks.HubbleMediaTask;
import com.thingspace.media.tasks.RetrieveMusicArtistsTask;

/**
 * MusicArtistListFragment is called when "Artists" Tab is selected in Music which retrieves and displays Music artists stored in the cloud.
 * When an artist name is clicked, it calls ArtistGenreFilesActivity which displays contents/files of the artist selected.
 */
public class MusicArtistListFragment extends BaseFragment implements OnBindViewInterface {

    public void executeQuery() {
        /**
         * RetrieveMusicArtistsTask makes a Cloud SDK API call to retrieve all Music artists stored under user's cloud storage account.
         */
        RetrieveMusicArtistsTask retrieveMusicArtistsTask = new RetrieveMusicArtistsTask(getActivity(), this, cloudAPI);
        retrieveMusicArtistsTask.execute();
    }

    protected int getLayoutType() {
        return LAYOUT_TYPE_LIST;
    }

    protected RecyclerView.Adapter getRecyclerViewAdapter(ItemList itemList) {
        return new RecyclerViewListAdapter(R.layout.list_item, itemList, this, this);
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
        ((RecyclerViewListHolder) holder).textView.setText(((Artist) item).getName());
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_MUSIC_ARTIST) {
            if (response == null || !(response instanceof ItemList)) {
                return;
            }

            itemList = (ItemList<Artist>) response;
            recyclerView.setAdapter(getRecyclerViewAdapter(itemList));
            return;
        }

        super.onResponse(taskCode, errorCode, response);
    }

    /**
     * When artist name is clicked, ArtistGenreFilesActivity is called which displays the files inside the album.
     * @param view
     * @param position
     */
    @Override
    public void onListItemClicked(View view, int position) {
        ArtistGenreFilesActivity.setArtist((Artist) itemList.getItem(position));
        Intent intent = new Intent(getActivity(), ArtistGenreFilesActivity.class);
        intent.putExtra(ArtistGenreFilesActivity.EXTRA_CONTENT_TYPE, ArtistGenreFilesActivity.CONTENT_TYPE_ARTIST);
        startActivity(intent);
    }
}
