/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.media.listeners.ThingspaceResponseListener;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate Cloud SDK api call to retrieve information about all the files stored under user's cloud storage account
 */
public class RetrieveFullViewTask extends HubbleMediaTask {

    private boolean delta;
    private CloudAPI cloudAPI;

    /**
     * Retrieve information about all the files stored under user's cloud storage account
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     */
    public RetrieveFullViewTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI) {
        this(context, thingspaceResponseListener, cloudAPI, false);
    }

    /**
     * Retrieve information about all the files stored under user's cloud storage account
     *
     * @param context  context object
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     * @param delta    true if only the changed files requested, false to retrieve all the files.
     */
    public RetrieveFullViewTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, boolean delta) {
        super(context, thingspaceResponseListener);
        this.delta = delta;
        this.cloudAPI = cloudAPI;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve information about all the files stored in the cloud.
         */
        ItemList itemList = cloudAPI.fullview(contextWeakReference.get());
        itemList.close(); // we are not processing this ItemList, but executing the search api call.
        return HttpsURLConnection.HTTP_OK;
    }

    @Override
    protected int getTaskCode() {
        return delta ? TASK_DELTA : TASK_FULLVIEW;
    }
}
