/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.media.listeners.ThingspaceResponseListener;

/**
 * Class to demonstrate Cloud SDK api call to retrieve all Music genres stored under user's cloud storage account
 */
public class RetrieveMusicGenresTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;

    /**
     * Retrieve all Music genres stored under user's cloud storage account
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     */
    public RetrieveMusicGenresTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve all music genres from the cloud.
         */
        return cloudAPI.getGenres(contextWeakReference.get());
    }

    @Override
    protected int getTaskCode() {
        return TASK_MUSIC_GENRE;
    }
}
