/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.cloud.sdk.list.item.Playlist;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK api call to retrieve files from an existing Playlist.
 */
public class GetPlaylistFilesTask extends HubbleMediaTask {

    private Playlist playlist;
    private SortType sortType;

    /**
     * Retrieve files from an existing Playlist.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param playlist                   {@link Playlist} object to access Playlist files
     * @param sortType                   Sort order for the response list
     */
    public GetPlaylistFilesTask(Context context, ThingspaceResponseListener thingspaceResponseListener, Playlist playlist, SortType sortType) {
        super(context, thingspaceResponseListener);
        this.playlist = playlist;
        this.sortType = sortType;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve files from this playlist.
         */
        return playlist.getFiles(contextWeakReference.get(), sortType);
    }

    @Override
    protected int getTaskCode() {
        return TASK_PLAYLIST_FILES;
    }
}
