/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.share;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.item.Share;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK api call to delete a Share.
 */
public class DeleteSharesTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String uid;

    /**
     * Delete a Share
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param uid                        Share unique identifier as obtained from {@link Share#getUid()}
     */
    public DeleteSharesTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String uid) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.uid = uid;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK method call to delete a share
         */
        return cloudAPI.deleteShare(contextWeakReference.get(), uid);
    }

    protected Object onCloudAPIException(CloudAPIException ex) {
        return false;
    }

    @Override
    protected int getTaskCode() {
        return TASK_DELETE_SHARE;
    }
}
