/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.tags;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.item.Audio;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.cloud.sdk.list.item.MetadataItem;
import com.thingspace.cloud.sdk.list.item.Photo;
import com.thingspace.cloud.sdk.list.item.Video;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK api to delete tags stored in the cloud for a file or folder.
 */
public class DeleteTagsTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String uri;

    /**
     * Delete tags stored in the cloud for a file or folder.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param uri                        The uri to the file or folder for which tags are to be removed. Uri can be retrieved using {@link Photo#getUri()}, {@link Video#getUri()}, {@link Audio#getUri()}, {@link File#getUri()}, {@link FullviewItem#getUri()}, {@link MetadataItem#getUri()}.
     */
    public DeleteTagsTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String uri) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.uri = uri;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to delete tags stored in the cloud for a file or folder.
         */
        return cloudAPI.deleteTags(contextWeakReference.get(), uri);
    }

    @Override
    protected int getTaskCode() {
        return TASK_DELETE_TAGS;
    }
}
