/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.tags;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.item.Audio;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.cloud.sdk.list.item.MetadataItem;
import com.thingspace.cloud.sdk.list.item.Photo;
import com.thingspace.cloud.sdk.list.item.Video;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK api to retrieve tags stored in the cloud for a file or folder.
 */
public class GetTagsTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String path;

    /**
     * Retrieve tags stored in the cloud for a file or folder.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param path                       The path to the file or folder for which tags are to be retrieved. Path can be created by combining parentPath + "/" + fileName.  Parent path and file names can be found in classes {@link Photo}, {@link Video}, {@link Audio}, {@link File}, {@link FullviewItem}, {@link MetadataItem}.
     */
    public GetTagsTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String path) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.path = path;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve tags stored in the cloud for a file or folder.
         */
        return cloudAPI.getTags(contextWeakReference.get(), path);
    }

    @Override
    protected int getTaskCode() {
        return TASK_GET_TAGS;
    }
}
