/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.activity;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.GridView;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.files.R;
import com.thingspace.files.adapters.DataClassGridAdapter;
import com.thingspace.files.listeners.DataFileOperationsResponseListener;
import com.thingspace.files.listeners.MetadataResponseListener;
import com.thingspace.files.listeners.OnUploadDownloadResponseListener;
import com.thingspace.files.task.DataClassTask;
import com.thingspace.files.task.DataFileDeteleTask;
import com.thingspace.files.task.DataFileDownloadTask;
import com.thingspace.files.task.DataFileFOPSTask;
import com.thingspace.files.utils.KeplerUtil;

import java.net.HttpURLConnection;

/**
 * Activity to display the Files/Folder View.Long pressing on the file/folder displays copy, move, delete, rename, download, fileinfo actions by calling this activity.
 * This activity calls {@link DataClassTask}, {@link DataFileFOPSTask}, {@link DataFileDeteleTask}, {@link DataFileDownloadTask} which in turn calls Cloud SDK APIs to perform corresponding functionalities.
 */
public class DataClassActivity extends BaseActivity implements DataFileOperationsResponseListener, MetadataResponseListener, OnUploadDownloadResponseListener {

    public static final String EXTRA_COPY_MOVE_ACTION = "copy_move_action";
    public static final String EXTRA_COPY_MOVE_CLASS_TYPE = "class_type";
    private static final String MEDIA_TYPE_IMAGE = "image";
    private static final int ACTION_COPY = 0;
    private static final int ACTION_MOVE = 1;
    private static final int ACTION_DELETE = 2;
    private static final int ACTION_RENAME = 3;
    private static final int ACTION_DOWNLOAD = 4;
    private static final int ACTION_FILEINFO = 5;
    private static final String RESPONSE_PARENTPATH = "parentPath";
    private static final String RESPONSE_NAME = "name";
    private static final String RESPONSE_VERSIONCREATED = "versionCreated";
    private ProgressDialog dialog;
    private GridView gridView;
    private DataClassGridAdapter dataAdapter;
    private ItemList<File> dataResponse;
    private String action;
    private File selectedFile;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        gridView = (GridView) findViewById(R.id.gridView);
        action = getIntent().getStringExtra("data_action");
    }

    private AdapterView.OnItemClickListener folderClick = new AdapterView.OnItemClickListener() {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
            selectedFile = dataResponse.getItem(position);
            if (selectedFile == null) {
                return;
            }

            if (selectedFile.getContentToken() != null) {
                if (selectedFile.getMimeType().contains(MEDIA_TYPE_IMAGE)) {
                    startGetFileTask(selectedFile.getParentPath(), selectedFile.getName(), selectedFile.getSize(), true);
                }
            } else {
                onAuthorizationComplete();
            }
        }
    };

    private AdapterView.OnItemLongClickListener fileLongClick = new AdapterView.OnItemLongClickListener() {
        @Override
        public boolean onItemLongClick(AdapterView<?> parent, View view, final int position, long id) {
            AlertDialog.Builder fileOperationDialog = new AlertDialog.Builder(DataClassActivity.this);
            selectedFile = dataResponse.getItem(position);
            if (selectedFile == null || "/".equals(selectedFile.getParentPath())) {
                return false;
            }

            final ArrayAdapter<String> arrayAdapter = new ArrayAdapter<String>(
                    DataClassActivity.this,
                    android.R.layout.simple_list_item_1);
            arrayAdapter.add(getString(R.string.action_copy));
            arrayAdapter.add(getString(R.string.action_move));
            arrayAdapter.add(getString(R.string.action_delete));
            arrayAdapter.add(getString(R.string.action_rename));

            if (selectedFile.getContentToken() != null) {
                arrayAdapter.add(getString(R.string.action_download));
                arrayAdapter.add(getString(R.string.action_file_info));
            }

            fileOperationDialog.setAdapter(arrayAdapter, new DialogInterface.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    switch (which) {
                        case ACTION_COPY:
                            moveCopyTask(ACTION_COPY);
                            break;

                        case ACTION_MOVE:
                            moveCopyTask(ACTION_MOVE);
                            break;

                        case ACTION_DELETE:
                            fileInfoAndDeleteTask(ACTION_DELETE, selectedFile);
                            break;

                        case ACTION_RENAME:
                            renameTask(selectedFile);
                            break;

                        case ACTION_DOWNLOAD:
                            downloadFile(selectedFile);
                            break;

                        case ACTION_FILEINFO:
                            fileInfoAndDeleteTask(ACTION_FILEINFO, selectedFile);
                            break;
                    }
                }
            });

            fileOperationDialog.setTitle(getString(R.string.file_actions));
            fileOperationDialog.create();
            fileOperationDialog.show();

            return true;
        }
    };


    /**
     * @param menu
     * @return
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return true;
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {
        return super.onPrepareOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        return super.onOptionsItemSelected(item);
    }

    protected void onAuthorizationComplete() {
        if (cloudAPI.hasAuthorization(this)) {
            showBusyDialog(true, getString(R.string.loading_busy_text));
            /**
             *  Retrieves photo/audio/video file types by making cloud SDK API calls
             */
            DataClassTask task = new DataClassTask(DataClassActivity.this, action, cloudAPI);
            task.execute();
        } else {
            reStartLogin();
        }
    }


    private void startGetFileTask(String path, String fileName, long size, boolean canDownload) {
        /**
         * Get full file and it's name,size and path by calling PhotoActivity
         */
        PhotoActivity.setCloudAPI(cloudAPI);
        Intent intent = new Intent(this, PhotoActivity.class);
        intent.putExtra(PhotoActivity.EXTRA_NAME, fileName);
        intent.putExtra(PhotoActivity.EXTRA_SIZE, size);
        intent.putExtra(PhotoActivity.EXTRA_PARENT_PATH, path);
        startActivity(intent);
    }

    private void renameTask(final File item) {
        AlertDialog.Builder renamePopup = new AlertDialog.Builder(DataClassActivity.this);
        final EditText input = new EditText(DataClassActivity.this);

        LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.MATCH_PARENT,
                LinearLayout.LayoutParams.MATCH_PARENT);
        input.setLayoutParams(lp);

        if (item != null) {
            input.setText(item.getName());
        }

        renamePopup.setView(input);
        renamePopup.setTitle(getString(R.string.action_rename)).setCancelable(false)
                .setMessage(getString(R.string.rename_dialog_message))
                .setPositiveButton(getString(R.string.action_ok), new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        if (input.getText().toString().isEmpty() || input.getText().toString().trim().isEmpty()) {
                            Toast.makeText(DataClassActivity.this, getString(R.string.enter_valid_name), Toast.LENGTH_SHORT).show();
                        } else {
                            if (!KeplerUtil.isNetworkAvailable(DataClassActivity.this)) {
                                Toast.makeText(DataClassActivity.this, getString(R.string.error_unavailable), Toast.LENGTH_SHORT).show();
                                return;
                            }
                            String src = item.getParentPath() + "/" + item.getName();
                            String target = item.getParentPath() + "/" + input.getText().toString();
                            if (src.equalsIgnoreCase(target)) {
                                Toast.makeText(DataClassActivity.this, getString(R.string.rename_name_same), Toast.LENGTH_SHORT).show();
                                return;
                            }
                            /**
                             * Rename a file/folder by making cloud SDK API call
                             */
                            DataFileFOPSTask task = new DataFileFOPSTask(DataClassActivity.this, DataClassActivity.this,
                                    item, getString(R.string.action_rename), target);
                            showBusyDialog(true, getString(R.string.loading_busy_text));
                            task.execute();
                        }
                    }
                }).setNegativeButton(getString(R.string.action_cancel), null).create();
        renamePopup.show();
    }

    /**
     * @param action
     * @param item
     */
    private void fileInfoAndDeleteTask(final int action, final File item) {
        if (item != null) {
            String title = "", dialogMessage = "";
            if (ACTION_DELETE == action) {
                title = getString(R.string.action_delete);
                dialogMessage = getString(R.string.delete_dialog_message);
            } else if (ACTION_FILEINFO == action) {
                // dialogMessage = getString(R.string.delete_dialog_message);
                title = getString(R.string.action_file_info);
                dialogMessage = RESPONSE_NAME + " : " + item.getName()
                        + "\n" + RESPONSE_PARENTPATH + " : " + item.getParentPath()
                        + "\n" + RESPONSE_VERSIONCREATED + " : " + item.getCreationDate();
            }


            AlertDialog.Builder deleteDialog = new AlertDialog.Builder(DataClassActivity.this)
                    .setTitle(title).setCancelable(false)
                    .setMessage(dialogMessage).setPositiveButton(ACTION_DELETE == action ? getString(R.string.action_yes)
                                    : getString(R.string.action_ok),
                            new DialogInterface.OnClickListener() {
                                @Override
                                public void onClick(DialogInterface dialog, int which) {
                                    if (ACTION_DELETE == action) {
                                        if (!KeplerUtil.isNetworkAvailable(DataClassActivity.this)) {
                                            Toast.makeText(DataClassActivity.this, getString(R.string.error_unavailable), Toast.LENGTH_SHORT).show();
                                            return;
                                        }

                                        showBusyDialog(true, getString(R.string.loading_busy_text));
                                        /**
                                         *Delete file/folder by making a cloud SDK API call
                                         */
                                        DataFileDeteleTask task = new DataFileDeteleTask(DataClassActivity.this, DataClassActivity.this, item);
                                        task.execute();
                                    }
                                }
                            });
            if (ACTION_DELETE == action) {
                deleteDialog.setNegativeButton(getString(R.string.action_no), null);
            }
            deleteDialog.create();
            deleteDialog.show();
        }
    }

    /**
     * @param action
     */
    private void moveCopyTask(final int action) {
        /**
         * Copy or move the file/folder to destination path by calling CopyMoveActivity.
         */
        Intent intent = new Intent(DataClassActivity.this, CopyMoveActivity.class);
        intent.putExtra(EXTRA_COPY_MOVE_ACTION, action);
        intent.putExtra(EXTRA_COPY_MOVE_CLASS_TYPE, true);
        startActivityForResult(intent, action);
    }

    private void downloadFile(File item) {
        /**
         * Download a file by making cloud SDK API call
         */
        DataFileDownloadTask downloadTask = new DataFileDownloadTask(this, item);
        downloadTask.execute();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (data != null) {
            switch (requestCode) {
                case ACTION_MOVE:
                    /**
                     * Move a file/folder by making a cloud SDK API call
                     */
                    DataFileFOPSTask moveTask = new DataFileFOPSTask(DataClassActivity.this, DataClassActivity.this,
                            selectedFile, getString(R.string.action_move), data.getStringExtra("target"));
                    showBusyDialog(true, getString(R.string.loading_busy_text));
                    moveTask.execute();
                    break;
                case ACTION_COPY:
                    /**
                     * Copy a file/folder by making a cloud SDK API call
                     */
                    DataFileFOPSTask copyTask = new DataFileFOPSTask(DataClassActivity.this, DataClassActivity.this,
                            selectedFile, getString(R.string.action_copy), data.getStringExtra("target"));
                    showBusyDialog(true, getString(R.string.loading_busy_text));
                    copyTask.execute();
                    break;
            }
        }

        super.onActivityResult(requestCode, resultCode, data);
    }

    /**
     * Called when Metadata API response is received.
     *
     * @param response     List of file/folder response for cloud folder
     * @param responseCode HTTP Response code
     */
    @Override
    public void onMetadataResponseReceived(ItemList response, int responseCode) {
        showBusyDialog(false, null);
        this.invalidateOptionsMenu();

        if (responseCode == HttpURLConnection.HTTP_UNAUTHORIZED) {
            reStartLogin();
            return;
        }

        if (responseCode == HttpURLConnection.HTTP_UNAVAILABLE) {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_unavailable), Toast.LENGTH_SHORT).show();
            return;
        }

        if (response == null || responseCode != HttpURLConnection.HTTP_OK) {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
            return;
        }

        // Response is OK
        if (response.getCount() == 0) {
            Toast.makeText(DataClassActivity.this, getString(R.string.no_files_to_display), Toast.LENGTH_SHORT).show();
            finish();
        }
        this.dataResponse = response;
        dataAdapter = new DataClassGridAdapter(this, cloudAPI, R.layout.grid_item, response);
        gridView.setAdapter(dataAdapter);

        gridView.setOnItemClickListener(folderClick);
        gridView.setOnItemLongClickListener(fileLongClick);

    }

    /**
     * Called when Download file API response is received.
     *
     * @param response     Get file response
     * @param responseCode HTTP Response code
     */
    @Override
    public void onGetFileResponseReceived(String response, int responseCode) {
        showBusyDialog(false, null);
        if (responseCode == HttpURLConnection.HTTP_OK) {
            Toast.makeText(DataClassActivity.this, response, Toast.LENGTH_SHORT).show();
        } else if (responseCode == HttpURLConnection.HTTP_UNAUTHORIZED) {
            reStartLogin();
        } else {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Called when Rename file API response is received.
     *
     * @param file
     */
    @Override
    public void onDataRenameResponseReceived(File file) {
        showBusyDialog(false, null);
        if (file != null) {
            Toast.makeText(DataClassActivity.this, getString(R.string.toast_rename_message), Toast.LENGTH_SHORT).show();
            onAuthorizationComplete();
        } else {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Called when copy file API response is received.
     *
     * @param file
     */
    @Override
    public void onDataCopyResponseReceived(File file) {
        showBusyDialog(false, null);
        if (file != null) {
            Toast.makeText(DataClassActivity.this, getString(R.string.toast_copy_message), Toast.LENGTH_SHORT).show();
            onAuthorizationComplete();
        } else {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Called when Move file API response is received.
     *
     * @param file
     */
    @Override
    public void onDataMoveResponseReceived(File file) {
        showBusyDialog(false, null);
        if (file != null) {
            Toast.makeText(DataClassActivity.this, getString(R.string.toast_move_message), Toast.LENGTH_SHORT).show();
            onAuthorizationComplete();
        } else {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Called when Delete file API response is received.
     *
     * @param response
     */
    public void onDataFileDeleteResponseReceived(boolean response) {
        showBusyDialog(false, null);
        if (!response) {
            Toast.makeText(DataClassActivity.this, getString(R.string.error_happened), Toast.LENGTH_SHORT).show();
            return;
        }

        if (response) {
            Toast.makeText(DataClassActivity.this, getString(R.string.delete_completed), Toast.LENGTH_SHORT).show();
            onAuthorizationComplete();
        }
    }

    /**
     * Called when Upload file API response is received.
     *
     * @param response     Upload boolean response
     * @param responseCode HTTP Response code
     */
    @Override
    public void onUploadDownloadResponseReceived(boolean response, int responseCode) {
        showBusyDialog(false, null);
    }

    public void showBusyDialog(boolean show, String message) {
        if (dialog == null && show) {
            dialog = new ProgressDialog(DataClassActivity.this);
            dialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            dialog.setMessage(message);
            dialog.setIndeterminate(true);
            dialog.setCanceledOnTouchOutside(false);
            dialog.show();
        } else if (dialog != null && !show) {
            dialog.dismiss();
            dialog = null;

        }
    }

    /**
     * Called to Re-Launch the app when there is a invalid/expired token
     */
    private void reStartLogin() {
        Toast.makeText(DataClassActivity.this, getString(R.string.error_unathorized), Toast.LENGTH_SHORT).show();
        cloudAPI.logout(this);
        Intent intent = new Intent(DataClassActivity.this, DataClassActivity.class);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        startActivity(intent);
    }
}