/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.adapters;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.files.R;
import com.thingspace.files.adapters.viewholders.RecyclerViewGridHolder;
import com.thingspace.files.cache.ImageCache;
import com.thingspace.files.cache.ImageFetcher;
import com.thingspace.files.listeners.RecyclerViewClickListener;

/**
 * GridCursorAdapter to inflate grid items
 */
public class RecyclerViewGridAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

    private static ImageFetcher staticImageFetcher;

    private Context context;
    private int layoutID;
    private ItemList itemList;
    private RecyclerViewClickListener recyclerViewClickListener;
    private CloudAPI cloudAPI;

    /**
     * Inflate grid items and retrieve content tokens from SQLite to display thumbnails.
     *
     * @param context                   context to initiate SimpleCursorAdapter and invoke inflater.
     * @param layout                    resource identifier of a layout file that defines the views for this list item. The layout file should include at least those named views defined in "to"
     * @param itemList                  List of searched file/folder item
     * @param cloudAPI                  CloudAPI object.
     * @param recyclerViewClickListener Callback listener
     */
    public RecyclerViewGridAdapter(Context context, int layout, ItemList itemList, CloudAPI cloudAPI, RecyclerViewClickListener recyclerViewClickListener) {
        this.context = context;
        this.layoutID = layout;
        this.cloudAPI = cloudAPI;
        this.itemList = itemList;
        this.recyclerViewClickListener = recyclerViewClickListener;
    }

    public ImageFetcher getImageFetcher() {
        if (staticImageFetcher == null) {
            ImageCache.ImageCacheParams cacheParams = new ImageCache.ImageCacheParams(context, "thumbs");
            cacheParams.setMemCacheSizePercent(context, 0.5f);

            staticImageFetcher = new ImageFetcher(context, context.getResources().getDimensionPixelSize(R.dimen.photo_item_size));
            staticImageFetcher.addImageCache(cacheParams);
        }
        return staticImageFetcher;
    }

    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        // Create a new view.
        View v = LayoutInflater.from(parent.getContext()).inflate(layoutID, parent, false);
        return new RecyclerViewGridHolder(v, recyclerViewClickListener);
    }

    @Override
    public void onBindViewHolder(RecyclerView.ViewHolder holder, int position) {
        FullviewItem fullviewItem = (FullviewItem) itemList.getItem(position);
        String mimeType = fullviewItem.getMimeType();//cursor.getString(cursor.getColumnIndex(FullViewResourceTable.COLUMN_MIME_TYPE));
        if (mimeType.indexOf("audio") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.music_icon);
        } else if (mimeType.indexOf("video") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.videos_icon);
        } else if (mimeType.indexOf("image") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.thumb_placeholder);
        } else if (mimeType.indexOf("directory") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.folder_icon);
        } else {
            getImageFetcher().setLoadingImage(R.drawable.file_icon);
        }

        getImageFetcher().loadImage(fullviewItem.getContentToken(), ((RecyclerViewGridHolder) holder).imageView, cloudAPI);

    }

    @Override
    public int getItemCount() {
        if (itemList != null) {
            return itemList.getCount();
        }
        return 0;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }
}
