/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.adapters;

import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.files.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.files.listeners.RecyclerViewClickListener;

/**
 * GridCursorAdapter to inflate grid items
 */
public class RecyclerViewListAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

    private int layoutID;
    private ItemList itemList;
    private OnBindViewInterface onBindViewInterface;
    private RecyclerViewClickListener recyclerViewClickListener;

    /**
     * Inflate grid items and retrieve content tokens from SQLite to display thumbnails.
     *
     * @param layoutID
     * @param itemList
     * @param onBindViewInterface
     * @param recyclerViewClickListener
     */
    public RecyclerViewListAdapter(int layoutID, ItemList itemList, OnBindViewInterface onBindViewInterface, RecyclerViewClickListener recyclerViewClickListener) {
        this.layoutID = layoutID;
        this.itemList = itemList;
        this.onBindViewInterface = onBindViewInterface;
        this.recyclerViewClickListener = recyclerViewClickListener;
    }

    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        // Create a new view.
        View v = LayoutInflater.from(parent.getContext()).inflate(layoutID, parent, false);
        return new RecyclerViewListHolder(v, recyclerViewClickListener);
    }

    @Override
    public void onBindViewHolder(RecyclerView.ViewHolder holder, int position) {
        FullviewItem fullviewItem = (FullviewItem) itemList.getItem(position);
        onBindViewInterface.onBindView(holder, fullviewItem);
    }

    @Override
    public int getItemCount() {
        if (itemList != null) {
            return itemList.getCount();
        }
        return 0;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }
}
