/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.app.Activity;
import android.os.AsyncTask;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.files.R;
import com.thingspace.files.listeners.MetadataResponseListener;

import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to Data types.
 */
public class DataClassTask extends AsyncTask<String, Void, ItemList> {

    private WeakReference<Activity> activityWeakReference;
    private String action;
    private CloudAPI cloudAPI;
    private int responseCode = -1;

    /**
     * Retrieves photo/audio/video data types by making cloud SDK API calls
     *
     * @param activity Calling activity context
     * @param action   File Type to be retrieved
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     */
    public DataClassTask(Activity activity, String action, CloudAPI cloudAPI) {
        activityWeakReference = new WeakReference<>(activity);
        this.action = action;
        this.cloudAPI = cloudAPI;
    }

    @Override
    protected ItemList doInBackground(String... params) {
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }
        try {
            if (action.equals(activityWeakReference.get().getString(R.string.action_photo))) {
                return cloudAPI.getPhotos(activityWeakReference.get(), SortType.NAME);
            } else if (action.equals(activityWeakReference.get().getString(R.string.action_audio))) {
                return cloudAPI.getAudios(activityWeakReference.get(), SortType.NAME);
            } else if (action.equals(activityWeakReference.get().getString(R.string.action_video))) {
                return cloudAPI.getVideos(activityWeakReference.get(), SortType.NAME);
            }
        } catch (CloudAPIException cloudAPIException) {
            if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                this.responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }
        }
        return null;
    }

    @Override
    protected void onPostExecute(ItemList response) {
        super.onPostExecute(response);
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        if (activityWeakReference.get() instanceof MetadataResponseListener) {
            ((MetadataResponseListener) activityWeakReference.get()).onMetadataResponseReceived(response, response != null ? HttpsURLConnection.HTTP_OK : this.responseCode);
        }
    }
}
