/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.files.listeners.DataFileOperationsResponseListener;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate API call to delete files/folder from data type class.
 */
public class DataFileDeteleTask extends AsyncTask<String, Void, Boolean> {

    private WeakReference<DataFileOperationsResponseListener> fileOperationsResponseListener;
    private File file;
    private Context context;

    /**
     * Delete file/folder using data type
     *
     * @param context  Calling activity context
     * @param listener {@link DataFileOperationsResponseListener}File operation response listener
     * @param file     {@link File}File to be deleted.
     */
    public DataFileDeteleTask(Context context, DataFileOperationsResponseListener listener, File file) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.file = file;
    }

    @Override
    protected Boolean doInBackground(String... params) {
        try {
            return file.delete(this.context, false);
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception retrieving resources: " + ex);
        }
        return false;
    }

    @Override
    protected void onPostExecute(Boolean response) {
        super.onPostExecute(response);
        fileOperationsResponseListener.get().onDataFileDeleteResponseReceived(response);
    }
}