/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Environment;
import android.util.Log;
import android.widget.Toast;

import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.files.R;
import com.thingspace.files.listeners.OnUploadDownloadResponseListener;

import java.io.File;
import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to download a file using data type object.
 */
public class DataFileDownloadTask extends AsyncTask<String, Void, Boolean> {

    private WeakReference<Activity> activityWeakReference;
    private com.thingspace.cloud.sdk.list.item.File file;
    private int responseCode = -1;

    /**
     * @param activity Calling activity context
     * @param file     File to be downloaded
     */
    public DataFileDownloadTask(Activity activity, com.thingspace.cloud.sdk.list.item.File file) {
        activityWeakReference = new WeakReference<>(activity);
        this.file = file;
    }

    @Override
    protected Boolean doInBackground(String... params) {
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        File sdcard = Environment.getExternalStorageDirectory();
        File folder = new File(sdcard.getAbsoluteFile(), "VZDemoApp");
        folder.mkdir();

        try {
            file.download(activityWeakReference.get(), folder.getAbsolutePath());
            return true;
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception downloading file: " + ex);
            if (ex.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                this.responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (ex.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }
        }
        return false;
    }

    /**
     * @param result
     */
    @Override
    protected void onPostExecute(Boolean result) {
        super.onPostExecute(result);
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }
        if (this.responseCode == HttpsURLConnection.HTTP_UNAUTHORIZED || this.responseCode == HttpsURLConnection.HTTP_UNAVAILABLE) {
            ((OnUploadDownloadResponseListener) activityWeakReference.get()).onUploadDownloadResponseReceived(false, this.responseCode);
            return;
        }
        Toast.makeText(activityWeakReference.get(), activityWeakReference.get().getString(result.booleanValue() ? R.string.file_downloaded : R.string.file_not_downloaded), Toast.LENGTH_SHORT).show();
    }
}
