/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.files.listeners.FileOperationsResponseListener;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate API call to Delete a file/folder in target path.
 */
public class DeleteFileFolderTask extends AsyncTask<String, Void, Boolean> {

    private WeakReference<FileOperationsResponseListener> fileOperationsResponseListener;
    private String path;
    private CloudAPI cloudAPI;
    private Context context;

    /**
     * Deletes File/Folder from target path in cloud.
     *
     * @param context  Calling activity context
     * @param listener {@link FileOperationsResponseListener} File operation response listener
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     * @param path     Path of file/folder to be deleted in cloud
     */
    public DeleteFileFolderTask(Context context, FileOperationsResponseListener listener, CloudAPI cloudAPI, String path) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.cloudAPI = cloudAPI;
        this.path = path;
    }

    @Override
    protected Boolean doInBackground(String... params) {
        try {
            /**
             * Cloud SDK method call to delete a file/folder.
             */
            return cloudAPI.delete(this.context, path, false);
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception retrieving resources: " + ex);
        }
        return false;
    }

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(Boolean response) {
        super.onPostExecute(response);
        fileOperationsResponseListener.get().onDeleteResponseReceived(response);
    }
}