/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;

import com.thingspace.cloud.sdk.CloudAPI;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate API call to download a file in device path.
 */
public class GetFileTask extends AsyncTask<String, Void, Bitmap> {

    private final WeakReference<ImageView> imageViewWeakReference;
    protected String fileName;
    private WeakReference<Context> contextWeakReference;
    private String parentPath;
    private ProgressBar progressBar;
    private CloudAPI cloudAPI;

    /**
     * Get full file from the cloud.
     *
     * @param parentPath  Path of the folder where file is stored
     * @param fileName    File name
     * @param cloudAPI    {@link CloudAPI} object to access Cloud api
     * @param imageView   Image view to bind the bitmap with
     * @param context     Context to read server url from the resource file
     * @param progressBar ProgressBar object to display/hide the progress
     */
    public GetFileTask(String parentPath, String fileName, CloudAPI cloudAPI, ImageView imageView, Context context, ProgressBar progressBar) {
        this.parentPath = parentPath;
        this.fileName = fileName;
        imageViewWeakReference = new WeakReference<>(imageView);
        this.progressBar = progressBar;
        this.cloudAPI = cloudAPI;
        this.contextWeakReference = new WeakReference<>(context);
    }

    @Override
    protected Bitmap doInBackground(String... params) {
        if (contextWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = 2;
        if (isCancelled()) {
            return null;
        }
        /**
         * Cloud SDK api call to retrieve a file.
         */
        return BitmapFactory.decodeStream(cloudAPI.downloadFile(contextWeakReference.get(), parentPath, fileName), null, options);
    }

    @Override
    protected void onPostExecute(Bitmap bitmap) {
        super.onPostExecute(bitmap);
        progressBar.setVisibility(View.GONE);
        if (imageViewWeakReference != null || bitmap != null) {
            ImageView imageView = imageViewWeakReference.get();
            if (imageView != null && bitmap != null) {
                imageView.setImageBitmap(bitmap);
            }
        } else {
            Log.e(getClass().getSimpleName(), "imageview weak reference null");
        }
    }
}
