/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.app.Activity;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.files.listeners.MetadataResponseListener;

import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to retrieve deleted file/folder details.
 */
public class TrashCanTask extends AsyncTask<String, Void, ItemList> {

    private WeakReference<Activity> activityWeakReference;
    private CloudAPI cloudAPI;
    private int responseCode = -1;

    /**
     * Retrieves deleted items from cloud
     *
     * @param activity Calling activity context
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     */
    public TrashCanTask(Activity activity, CloudAPI cloudAPI) {
        activityWeakReference = new WeakReference<>(activity);
        this.cloudAPI = cloudAPI;
    }

    /**
     * @param params
     * @return
     */
    @Override
    protected ItemList doInBackground(String... params) {
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }
        try {
            /**
             * Cloud SDK method call to retrieve deleted file/folder
             */
            return cloudAPI.getTrash(activityWeakReference.get(), SortType.NAME, 0, 0, null, false);
        } catch (CloudAPIException cloudAPIException) {
            Log.e(getClass().getSimpleName(), "Exception retrieving trash - " + cloudAPIException);
            if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                this.responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }
        }
        return null;
    }

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(ItemList response) {
        super.onPostExecute(response);
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        if (activityWeakReference.get() instanceof MetadataResponseListener) {
            ((MetadataResponseListener) activityWeakReference.get()).onMetadataResponseReceived(response, response != null ? HttpsURLConnection.HTTP_OK : this.responseCode);
        }
    }
}
